Index: /issm/trunk/externalpackages/petsc/install.sh
===================================================================
--- /issm/trunk/externalpackages/petsc/install.sh	(revision 6879)
+++ /issm/trunk/externalpackages/petsc/install.sh	(revision 6880)
@@ -3,8 +3,4 @@
 #Get number of cpus on current platform
 NUMCPUS=$1;
-
-#available versions
-#2.3.2-p3
-#3.0.0-p11
 
 #version of petsc?
@@ -13,32 +9,26 @@
 
 #Some cleanup
-rm -rf install petsc-$version
+rm -rf install petsc-$version src
 
 #Create src and install directories
-mkdir install
+mkdir install src
 
 #Untar 
 tar -zxvf  petsc-$version.tar.gz
 
-#Move petsc to install directory
-rm -rf install/*
-mv petsc-$version/* install/
-rm -rf petsc-$version
+#Move petsc to install directory or src depending on the version
+if [[ $version == "3.1-p7" ]]
+then	
+	mv petsc-$version/* src/
+	rm -rf petsc-$version
+	cd src
+else
+	mv petsc-$version/* install/
+	rm -rf petsc-$version
+	cd install
+fi
 
-#Configure petsc
-cd install
+#configure
 ../configure.sh
-
-#symlink some missing stuff.
-if [[ $version == "3.0.0-p11" ]]
-then	
-	cd conf
-	ln -s ../$ISSM_ARCH/conf/petscrules petscrules 
-	ln -s ../$ISSM_ARCH/conf/petscvariables petscvariables 
-	cd ../
-	cd include
-	ln -s ../$ISSM_ARCH/include/petscconf.h petscconf.h 
-	cd ../
-fi
 
 #Compile petsc and install it
